@@ -86,14 +86,14 @@ void KigPainter::drawCircle( const Coordinate& center, double radius )
   Coordinate bottomLeft = center - Coordinate(radius, radius);
   Coordinate topRight = center + Coordinate(radius, radius);
   Rect r( bottomLeft, topRight );
-  QRect qr = toScreen( r );
+  QRectF qr = toScreenF( r );
   mP.drawEllipse ( qr );
   if( mNeedOverlay ) circleOverlay( center, radius );
 }
 
 void KigPainter::drawSegment( const Coordinate& from, const Coordinate& to )
 {
-  QPoint tF = toScreen(from), tT = toScreen(to);
+  QPointF tF = toScreenF(from), tT = toScreenF(to);
   mP.drawLine( tF, tT );
   if( mNeedOverlay ) segmentOverlay( from, to );
 }
@@ -506,6 +506,11 @@ QPoint KigPainter::toScreen( const Coordinate& p ) const
   return msi.toScreen( p );
 }
 
+QPointF KigPainter::toScreenF( const Coordinate& p ) const
+{
+  return msi.toScreenF( p );
+}
+
 void KigPainter::drawGrid( const CoordinateSystem& c, bool showGrid, bool showAxes )
 {
   c.drawGrid( *this, showGrid, showAxes );
@@ -549,6 +554,11 @@ QRect KigPainter::toScreen( const Rect& r ) const
   return msi.toScreen( r );
 }
 
+QRectF KigPainter::toScreenF( const Rect& r ) const
+{
+  return msi.toScreenF( r );
+}
+
 QRect KigPainter::toScreenEnlarge( const Rect& r ) const
 {
   if ( overlayenlarge == 0 ) return msi.toScreen( r );
@@ -973,7 +983,7 @@ void KigPainter::drawArc( const Coordinate& center, double radius,
   { 
     Rect krect( 0, 0, 2*radius, 2*radius );
     krect.setCenter( center );
-    QRect rect = toScreen( krect );
+    QRectF rect = toScreenF( krect );
 
     mP.drawArc( rect, startangle, angle );
     setWholeWinOverlay();
